==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/HTTPCookieFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HTTPCookieFluentImpl<A extends HTTPCookieFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HTTPCookieFluent<A>{

    private String name;
    private String path;
    private Long ttl;

    public HTTPCookieFluentImpl(){
    }
    public HTTPCookieFluentImpl(HTTPCookie instance){
            this.withName(instance.getName()); 
            this.withPath(instance.getPath()); 
            this.withTtl(instance.getTtl()); 
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public Long getTtl(){
            return this.ttl;
    }

    public A withTtl(Long ttl){
            this.ttl=ttl; return (A) this;
    }

    public Boolean hasTtl(){
            return this.ttl != null;
    }

    public A withNewTtl(String arg1){
            return (A)withTtl(new Long(arg1));
    }

    public A withNewTtl(long arg1){
            return (A)withTtl(new Long(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HTTPCookieFluentImpl that = (HTTPCookieFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            if (ttl != null ? !ttl.equals(that.ttl) :that.ttl != null) return false;
            return true;
    }




}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/HTTPCookieFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HTTPCookieFluentImpl<A extends HTTPCookieFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HTTPCookieFluent<A>{

    private String name;
    private String path;
    private Integer ttl;

    public HTTPCookieFluentImpl(){
    }
    public HTTPCookieFluentImpl(HTTPCookie instance){
            this.withName(instance.getName()); 
            this.withPath(instance.getPath()); 
            this.withTtl(instance.getTtl()); 
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public A withNewPath(String arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1){
            return (A)withPath(new String(arg1));
    }

    public Integer getTtl(){
            return this.ttl;
    }

    public A withTtl(Integer ttl){
            this.ttl=ttl; return (A) this;
    }

    public Boolean hasTtl(){
            return this.ttl != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            HTTPCookieFluentImpl that = (HTTPCookieFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            if (ttl != null ? !ttl.equals(that.ttl) :that.ttl != null) return false;
            return true;
    }




}
